pub struct Next<'a> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a> Next<'a>
impl<'a> Next<'a>
Sourcepub fn run(
self,
job: &'a Job,
ctx: &'a WorkerContext,
) -> Pin<Box<dyn Future<Output = Result<WorkerResult>> + Send + 'a>>
pub fn run( self, job: &'a Job, ctx: &'a WorkerContext, ) -> Pin<Box<dyn Future<Output = Result<WorkerResult>> + Send + 'a>>
Invoke the next middleware in the stack, or the terminal
worker.execute if this is the innermost layer.
Returns a boxed future so the recursion through an unknown-depth
middleware stack stays Sized.